# learning-hypermodern
[![Tests](https://github.com/abstractlyZach/learning-hypermodern/workflows/Tests/badge.svg)](https://github.com/abstractlyZach/learning-hypermodern/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/abstractlyZach/learning-hypermodern/branch/master/graph/badge.svg)](https://codecov.io/gh/abstractlyZach/learning-hypermodern)
[![PyPI](https://img.shields.io/pypi/v/learning-hypermodern.svg)](https://pypi.org/project/learning-hypermodern/)



Learning Hypermodern Python through this article: https://cjolowicz.github.io/posts/hypermodern-python-01-setup/
